﻿Public Class Form1
    ' The database context.
    Private OrderContext As OrdersDatabaseEntities

    ' Load the data.
    Private Sub Form1_Load(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles MyBase.Load
        ' Load the data.
        OrderContext = New OrdersDatabaseEntities()

        ' Select the Customers.
        Dim customersQuery =
            From cust As Customer In OrderContext.Customers
            Order By cust.FirstName, cust.LastName
            Select New CustomerWithName With
            {
                .Customer = cust,
                .FullName = cust.FirstName & " " & cust.LastName
            }

        ' Bind the Customers to the cboCustomer ComboBox.
        cboCustomers.DisplayMember = "FullName"
        cboCustomers.DataSource = customersQuery.ToArray()
    End Sub

    ' Dispose of the database.
    Private Sub Form1_FormClosing(ByVal sender As Object, ByVal e As System.Windows.Forms.FormClosingEventArgs) Handles Me.FormClosing
        OrderContext.Dispose()
    End Sub

    ' Display this customer's orders.
    Private Sub cboCustomers_SelectedIndexChanged(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles cboCustomers.SelectedIndexChanged
        If cboCustomers.SelectedItem Is Nothing Then Exit Sub

        ' Get the selected Customer.
        Dim custWithName As CustomerWithName =
            DirectCast(cboCustomers.SelectedItem, CustomerWithName)
        Dim cust As Customer = custWithName.Customer

        ' Display this customer's orders.
        dgvCustomerOrders.DataSource = cust.PurchaseOrders

        ' Hide navigation properties.
        dgvCustomerOrders.Columns("CustomerId").Visible = False
        dgvCustomerOrders.Columns("Customer").Visible = False
        dgvCustomerOrders.Columns("OrderItems").Visible = False

        ' Size the columns.
        dgvOrderItems.AutoResizeColumns()

        ' Select the first order (if there is one).
        If dgvCustomerOrders.Rows.Count > 0 Then
            dgvCustomerOrders.Rows(0).Selected = True
        End If
    End Sub

    ' Display this order's items.
    Private Sub dgvCustomerOrders_SelectionChanged(ByVal sender As Object, ByVal e As System.EventArgs) Handles dgvCustomerOrders.SelectionChanged
        If dgvCustomerOrders.SelectedRows.Count = 0 Then Exit Sub

        ' Display the selected purchase order's items.
        Dim po As PurchaseOrder = DirectCast(
            dgvCustomerOrders.SelectedRows(0).DataBoundItem, 
            PurchaseOrder)

        ' Display this order's items.
        If po Is Nothing Then
            ' There are no items to display.
            dgvOrderItems.DataSource = Nothing
        Else
            ' Display this order's items.
            dgvOrderItems.DataSource = po.OrderItems

            ' Hide navigation properties.
            dgvOrderItems.Columns("PurchaseOrder").Visible = False
            dgvOrderItems.Columns("OrderId").Visible = False

            ' Size the columns.
            dgvOrderItems.AutoResizeColumns()
        End If
    End Sub

    ' Save changes to the data.
    Private Sub btnSave_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles btnSave.Click
        Try
            OrderContext.SaveChanges()
            MessageBox.Show("Changes Saved", "Changes Saved",
                MessageBoxButtons.OK, MessageBoxIcon.Information)
        Catch ex As Exception
            Dim msg As String = ex.Message
            If ex.InnerException IsNot Nothing Then
                msg &= vbCrLf & vbCrLf & "***** Inner Exception *****" &
                    vbCrLf & ex.InnerException.Message
            End If
            MessageBox.Show(msg)
        End Try
    End Sub
End Class
